@@ -205,14 +205,9 @@ mfxStatus VideoDECODEAV1::Init(mfxVideoParam* par)
 
     m_init_par = (mfxVideoParamWrapper)(*par);
 
-    if (0 == m_init_par.mfx.FrameInfo.FrameRateExtN || 0 == m_init_par.mfx.FrameInfo.FrameRateExtD)
-    {
-        m_init_par.mfx.FrameInfo.FrameRateExtD = 1;
-        m_init_par.mfx.FrameInfo.FrameRateExtN = 30;
-    }
-
     m_first_par = m_init_par;
-    m_in_framerate = (mfxF64) m_first_par.mfx.FrameInfo.FrameRateExtD / m_first_par.mfx.FrameInfo.FrameRateExtN;
+    m_in_framerate = (m_first_par.mfx.FrameInfo.FrameRateExtD && m_first_par.mfx.FrameInfo.FrameRateExtN) ?
+        ((mfxF64) m_first_par.mfx.FrameInfo.FrameRateExtD / m_first_par.mfx.FrameInfo.FrameRateExtN) : (mfxF64)1.0 / 30;
     m_decoder->SetInFrameRate(m_in_framerate);
 
     //mfxFrameAllocResponse response{};
@@ -469,6 +464,9 @@ mfxStatus VideoDECODEAV1::Reset(mfxVideoParam* par)
 {
     std::lock_guard<std::mutex> guard(m_guard);
 
+    TRACE_EVENT(MFX_TRACE_API_DECODE_RESET_TASK, EVENT_TYPE_START, TR_KEY_MFX_API, make_event_data(par ? par->mfx.FrameInfo.Width : 0,
+        par ? par->mfx.FrameInfo.Height : 0, par ? par->mfx.CodecId : 0));
+
     MFX_CHECK_NULL_PTR1(par);
 
     MFX_CHECK(m_is_init, MFX_ERR_NOT_INITIALIZED);
@@ -506,15 +504,13 @@ mfxStatus VideoDECODEAV1::Reset(mfxVideoParam* par)
 
     m_first_par = *par;
 
-    if (0 == m_first_par.mfx.FrameInfo.FrameRateExtN || 0 == m_first_par.mfx.FrameInfo.FrameRateExtD)
-    {
-        m_first_par.mfx.FrameInfo.FrameRateExtD = 1;
-        m_first_par.mfx.FrameInfo.FrameRateExtN = 30;
-    }
+    m_in_framerate = (m_first_par.mfx.FrameInfo.FrameRateExtD && m_first_par.mfx.FrameInfo.FrameRateExtN) ?
+        ((mfxF64)m_first_par.mfx.FrameInfo.FrameRateExtD / m_first_par.mfx.FrameInfo.FrameRateExtN) : (mfxF64)1.0 / 30;
 
-    m_in_framerate = (mfxF64) m_first_par.mfx.FrameInfo.FrameRateExtD / m_first_par.mfx.FrameInfo.FrameRateExtN;
     m_decoder->SetInFrameRate(m_in_framerate);
 
+    TRACE_EVENT(MFX_TRACE_API_DECODE_RESET_TASK, EVENT_TYPE_END, TR_KEY_MFX_API, make_event_data(MFX_ERR_NONE));
+
     return MFX_ERR_NONE;
 }
 
@@ -709,6 +705,9 @@ mfxStatus VideoDECODEAV1::DecodeHeader(VideoCORE* core, mfxBitstream* bs, mfxVid
 
 mfxStatus VideoDECODEAV1::GetVideoParam(mfxVideoParam *par)
 {
+    TRACE_EVENT(MFX_TRACE_API_DECODE_GETVIDEOPARAM_TASK, EVENT_TYPE_START, TR_KEY_MFX_API, make_event_data(par ? par->mfx.FrameInfo.Width : 0,
+        par ? par->mfx.FrameInfo.Height : 0, par ? par->mfx.CodecId : 0));
+
     MFX_CHECK_NULL_PTR1(par);
     MFX_CHECK(m_decoder, MFX_ERR_NOT_INITIALIZED);
 
@@ -767,14 +766,20 @@ mfxStatus VideoDECODEAV1::GetVideoParam(mfxVideoParam *par)
         break;
     }
 
+    TRACE_EVENT(MFX_TRACE_API_DECODE_GETVIDEOPARAM_TASK, EVENT_TYPE_END, TR_KEY_MFX_API, make_event_data(MFX_ERR_NONE));
+
     return MFX_ERR_NONE;
 }
 
 
 mfxStatus VideoDECODEAV1::GetDecodeStat(mfxDecodeStat* stat)
 {
+    TRACE_EVENT(MFX_TRACE_API_DECODE_GETSTAT_TASK, EVENT_TYPE_START, TR_KEY_MFX_API, make_event_data(0));
+
     MFX_CHECK_NULL_PTR1(stat);
 
+    TRACE_EVENT(MFX_TRACE_API_DECODE_GETSTAT_TASK, EVENT_TYPE_END, TR_KEY_MFX_API, make_event_data(stat ? stat->NumFrame : 0, MFX_ERR_NONE));
+
     return MFX_ERR_NONE;
 }
 
@@ -898,9 +903,8 @@ mfxStatus VideoDECODEAV1::QueryFrame(mfxThreadTask task)
 
     if(info->copyfromframe != UMC::FRAME_MID_INVALID)
     {
-        frame = m_decoder->DecodeFrameID(info->copyfromframe);
+        frame = m_decoder->FindFrameByMemID(info->copyfromframe);
         MFX_CHECK(frame, MFX_ERR_UNDEFINED_BEHAVIOR);
-        frame->Repeated(false);
     }
     else
     {
@@ -918,7 +922,11 @@ mfxStatus VideoDECODEAV1::QueryFrame(mfxThreadTask task)
     }
     mfxStatus sts = DecodeFrame(surface_out, frame);
 
-    m_decoder->Flush();
+    //repeat frame decrease reference counter here
+    if (info->copyfromframe != UMC::FRAME_MID_INVALID)
+    {
+        m_decoder->FlushRepeatFrame(frame);
+    }
 
     MFX_CHECK_STS(sts);
     return MFX_TASK_DONE;
