@@ -1,4 +1,4 @@
-// Copyright (c) 2022-2024 Intel Corporation
+// Copyright (c) 2022-2025 Intel Corporation
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -63,6 +63,11 @@ namespace CommonCaps {
         return (platform != MFX_HW_DG2);
     }
 
+    inline bool IsSrAYUVorYUY2FormatSupported(eMFXHWType platform)
+    {
+        return (platform >= MFX_HW_LNL);
+    }
+
     inline bool IsVAEncSliceLPSupported(eMFXHWType platform)
     {
         return (platform < MFX_HW_MTL);
@@ -78,6 +83,12 @@ namespace CommonCaps {
     {
         return (platform >= MFX_HW_MTL);
     }
+
+    inline bool IsFastPassLASupported(eMFXHWType platform, mfxU16 ChromaFormat)
+    {
+        return ((platform == MFX_HW_BMG || platform >= MFX_HW_PTL)
+            && (ChromaFormat == MFX_CHROMAFORMAT_YUV420));
+    }
 }
 
 #ifdef MFX_ENABLE_H264_VIDEO_ENCODE
@@ -119,6 +130,7 @@ namespace H264ECaps {
         // VDEnc B frame supported from DG2
         return (platform >= MFX_HW_DG2);
     }
+
 }
 #endif //MFX_ENABLE_H264_VIDEO_ENCODE
 
