@@ -642,7 +642,7 @@ static bool QueryImplCaps(std::function < bool (VideoCORE&, mfxU32, mfxU32 , mfx
             FILE* file = fopen(path.c_str(), "r");
 
             if (!file)
-                break;
+                continue;
 
             int nread = fscanf(file, "%x", &vendorId);
             fclose(file);
@@ -657,7 +657,7 @@ static bool QueryImplCaps(std::function < bool (VideoCORE&, mfxU32, mfxU32 , mfx
 
             FILE* file = fopen(path.c_str(), "r");
             if (!file)
-                break;
+                continue;
 
             int nread = fscanf(file, "%x", &deviceId);
             fclose(file);
@@ -757,6 +757,10 @@ static void FillImplsDescription(mfx::ImplDescription& impl, VideoCORE& core, mf
         }
     }
 
+    impl.Dec.Version.Version = MFX_STRUCT_VERSION(1, 0);
+    impl.Enc.Version.Version = MFX_STRUCT_VERSION(1, 0);
+    impl.VPP.Version.Version = MFX_STRUCT_VERSION(1, 0);
+
     return;
 };
 
@@ -901,10 +905,6 @@ mfxHDL* MFX_CDECL MFXQueryImplsDescription(mfxImplCapsDeliveryFormat format, mfx
 
                 FillImplsDescription(impl, core, deviceId, adapterNum, subDevMask);
 
-                impl.Dec.Version.Version = MFX_STRUCT_VERSION(1, 0);
-                impl.Enc.Version.Version = MFX_STRUCT_VERSION(1, 0);
-                impl.VPP.Version.Version = MFX_STRUCT_VERSION(1, 0);
-
                 return (MFX_ERR_NONE == QueryImplsDescription(core, impl.Enc, impl) &&
                     MFX_ERR_NONE == QueryImplsDescription(core, impl.Dec, impl) &&
                     MFX_ERR_NONE == QueryImplsDescription(core, impl.VPP, impl));
@@ -1011,7 +1011,11 @@ static mfxStatus ProcessQueryPropToAction(mfxQueryProperty** properties, mfxU32
                 if (properties[i]->PropVar.Type != MFX_VARIANT_TYPE_U32)
                     MFX_RETURN(MFX_ERR_UNKNOWN);
 
-                propAction2Data[query_action].push_back(properties[i]->PropVar.Data.U32);
+                if (std::find(propAction2Data[query_action].begin(), propAction2Data[query_action].end(),
+                    properties[i]->PropVar.Data.U32) == propAction2Data[query_action].end())
+                {
+                    propAction2Data[query_action].push_back(properties[i]->PropVar.Data.U32);
+                }
 
                 break;
             }
@@ -1020,7 +1024,7 @@ static mfxStatus ProcessQueryPropToAction(mfxQueryProperty** properties, mfxU32
             case QueryProp_EncAll:
             case QueryProp_VPPAll:
             {
-                if (properties[i]->PropVar.Type != MFX_VARIANT_TYPE_QUERY)
+                if (properties[i]->PropVar.Type != MFX_VARIANT_TYPE_U32)
                     MFX_RETURN(MFX_ERR_UNKNOWN);
 
                 break;
@@ -1039,17 +1043,21 @@ static mfxStatus ProcessQueryPropToAction(mfxQueryProperty** properties, mfxU32
         || propAction[QueryProp_EncCodecID] || propAction[QueryProp_EncAll]
         || propAction[QueryProp_VPPFilterFourCC] || propAction[QueryProp_VPPAll];
 
+    // If request shallow query and query into codecs/vpp, will ignore shallow query
     if (propAction[QueryProp_ImplDescription] && query_into_codecs)
-        MFX_RETURN(MFX_ERR_UNKNOWN);
+        propAction[QueryProp_ImplDescription] = false;
 
+    // If request to query set of decoders and all decoders, will query all decoders
     if (propAction[QueryProp_DecCodecID] && propAction[QueryProp_DecAll])
-        MFX_RETURN(MFX_ERR_UNKNOWN);
+        propAction[QueryProp_DecCodecID] = false;
 
+    // If request to query set of encoders and all encoders, will query all encoders
     if (propAction[QueryProp_EncCodecID] && propAction[QueryProp_EncAll])
-        MFX_RETURN(MFX_ERR_UNKNOWN);
+        propAction[QueryProp_EncCodecID] = false;
 
+    // If request to query set of VPP filters and all VPP filters, will query all VPP filters
     if (propAction[QueryProp_VPPFilterFourCC] && propAction[QueryProp_VPPAll])
-        MFX_RETURN(MFX_ERR_UNKNOWN);
+        propAction[QueryProp_VPPFilterFourCC] = false;
 
     // QueryProp_All may be used for future property granularity extension, which will
     // be the default behavior if none of codecs or shallow capability are queried.
@@ -1105,10 +1113,6 @@ mfxHDL* MFX_CDECL MFXQueryImplsProperties(mfxQueryProperty** properties, mfxU32
 
             FillImplsDescription(impl, core, deviceId, adapterNum, subDevMask);
 
-            impl.Dec.Version.Version = MFX_STRUCT_VERSION(1, 0);
-            impl.Enc.Version.Version = MFX_STRUCT_VERSION(1, 0);
-            impl.VPP.Version.Version = MFX_STRUCT_VERSION(1, 0);
-
             if (propAction[QueryProp_EncCodecID])
             {
                 QueryImplsDescription(core, impl.Enc, impl, propAction2Data[QueryProp_EncCodecID]);
