@@ -140,7 +140,7 @@ mfxStatus CheckFrameInfoCommon(mfxFrameInfo  *info, mfxU32 codecId)
         if (   info->FourCC != MFX_FOURCC_P010 && info->FourCC != MFX_FOURCC_P210
             && info->FourCC != MFX_FOURCC_Y210
             && info->FourCC != MFX_FOURCC_P016 && info->FourCC != MFX_FOURCC_Y216
-            && info->FourCC != MFX_FOURCC_Y416)
+            && info->FourCC != MFX_FOURCC_Y416 && info->FourCC != MFX_FOURCC_R16)
             MFX_RETURN(MFX_ERR_INVALID_VIDEO_PARAM);
     }
     if (codecId != MFX_CODEC_JPEG)
@@ -1016,7 +1016,6 @@ void mfxVideoParamWrapper::CopyVideoParam(const mfxVideoParam & par)
     ExtParam = NumExtParam ? m_buffers.GetBuffers() : 0;
 }
 
-inline
 mfxU32 GetMinPitch(mfxU32 fourcc, mfxU16 width)
 {
     switch (fourcc)
