@@ -464,9 +464,9 @@ typedef struct {
     { 0xA78D, MFX_HW_ADL_S, MFX_GT1 },//RPL-S
     { 0xA78E, MFX_HW_ADL_S, MFX_GT1 },//RPL-S
 
-    { 0xA7AA, MFX_HW_ADL_S, MFX_GT1 },//RPL 
-    { 0xA7AB, MFX_HW_ADL_S, MFX_GT1 },//RPL 
-    { 0xA7AC, MFX_HW_ADL_S, MFX_GT1 },//RPL 
+    { 0xA7AA, MFX_HW_ADL_S, MFX_GT1 },//RPL
+    { 0xA7AB, MFX_HW_ADL_S, MFX_GT1 },//RPL
+    { 0xA7AC, MFX_HW_ADL_S, MFX_GT1 },//RPL
     { 0xA7AD, MFX_HW_ADL_S, MFX_GT1 },//RPL
 
     /* ADL-P */
@@ -592,7 +592,15 @@ typedef struct {
     { 0xE20B, MFX_HW_BMG, MFX_GT4 },
     { 0xE20C, MFX_HW_BMG, MFX_GT4 },
     { 0xE20D, MFX_HW_BMG, MFX_GT4 },
+    { 0xE210, MFX_HW_BMG, MFX_GT4 },
+    { 0xE211, MFX_HW_BMG, MFX_GT4 },
     { 0xE212, MFX_HW_BMG, MFX_GT4 },
+    { 0xE216, MFX_HW_BMG, MFX_GT4 },
+    /* BMG Plus */
+    { 0xE220, MFX_HW_BMG, MFX_GT4 },
+    { 0xE221, MFX_HW_BMG, MFX_GT4 },
+    { 0xE222, MFX_HW_BMG, MFX_GT4 },
+    { 0xE223, MFX_HW_BMG, MFX_GT4 },
 
     /* LNL */
     { 0x6420, MFX_HW_LNL, MFX_GT2 },
@@ -605,11 +613,20 @@ typedef struct {
     { 0xB081, MFX_HW_PTL, MFX_GT2 },
     { 0xB082, MFX_HW_PTL, MFX_GT2 },
     { 0xB083, MFX_HW_PTL, MFX_GT2 },
+    { 0xB084, MFX_HW_PTL, MFX_GT2 },
+    { 0xB085, MFX_HW_PTL, MFX_GT2 },
+    { 0xB086, MFX_HW_PTL, MFX_GT2 },
+    { 0xB087, MFX_HW_PTL, MFX_GT2 },
     { 0xB08F, MFX_HW_PTL, MFX_GT2 },
     { 0xB090, MFX_HW_PTL, MFX_GT2 },
     { 0xB0A0, MFX_HW_PTL, MFX_GT2 },
     { 0xB0B0, MFX_HW_PTL, MFX_GT2 },
 
+
+    /* WCL / Wildcat Lake */
+    { 0xFD80, MFX_HW_PTL, MFX_GT2 },
+    { 0xFD81, MFX_HW_PTL, MFX_GT2 },
+
 };
 
 enum
