@@ -1,4 +1,4 @@
-// Copyright (c) 2010-2020 Intel Corporation
+// Copyright (c) 2010-2024 Intel Corporation
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -21,6 +21,7 @@
 #include "mfxdefs.h"
 #include "mfx_trace.h"
 #include "mfx_utils_perf.h"
+#include "mfx_decode_dpb_logging.h"
 
 static mfx_reflect::AccessibleTypesCollection g_Reflection;
 
@@ -271,6 +272,17 @@ mfxTraceU32 MFXTrace_GetRegistryParams(void)
                         PerfUtility::perfFilePath = iter->second;
                     }
                 }
+                else if (iter->first == "VPL DPB LOG" && stoi(iter->second))
+                {
+                    dpb_logger = DPBLog::getInstance();
+                }
+                else if (iter->first == "VPL DPB PATH")
+                {
+                    if (!iter->second.empty())
+                    {
+                        DPBLog::dpbFilePath = iter->second;
+                    }
+                }
             }
         }
     }
@@ -315,7 +327,7 @@ inline bool MFXTrace_IsPrintableCategoryAndLevel(mfxTraceU32 m_OutputInitilized,
 {
     bool logFlag = false;
     if (m_OutputInitilized == MFX_TRACE_OUTPUT_TEXTLOG) {
-#ifndef NDEBUG
+
         if (g_Level == MFX_TXTLOG_LEVEL_MAX)
         {
             logFlag = true;
@@ -328,9 +340,6 @@ inline bool MFXTrace_IsPrintableCategoryAndLevel(mfxTraceU32 m_OutputInitilized,
             }
         }
         else if (g_Level == MFX_TXTLOG_LEVEL_API_AND_PARAMS)
-#else
-        if (g_Level == MFX_TXTLOG_LEVEL_API_AND_PARAMS)
-#endif
         {
             if (level == MFX_TRACE_LEVEL_API_PARAMS || level == MFX_TRACE_LEVEL_API)
             {
